==> component-web-spring-boot-starter-2.0.0-20200529.090318-28-sources.jar: com/bxm/newidea/component/config/ComponentWebAutoConfiguration.java <==
package com.bxm.newidea.component.config;

import com.bxm.newidea.component.mvc.ApiVersionRequestMapping;
import org.hibernate.validator.HibernateValidator;
import org.springframework.boot.autoconfigure.AutoConfigureAfter;
import org.springframework.boot.autoconfigure.web.servlet.WebMvcAutoConfiguration;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.validation.annotation.Validated;
import org.springframework.validation.beanvalidation.MethodValidationPostProcessor;
import org.springframework.web.servlet.mvc.method.annotation.RequestMappingHandlerMapping;

import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;

/**
 * 公共的web配置
 * @author liujia
 */
@Configuration
@AutoConfigureAfter(WebMvcAutoConfiguration.class)
@EnableConfigurationProperties(ComponentWebConfigurationProperties.class)
public class ComponentWebAutoConfiguration {

    private ComponentWebConfigurationProperties properties;

    public ComponentWebAutoConfiguration(ComponentWebConfigurationProperties properties) {
        this.properties = properties;
    }

    @Bean
    public RequestMappingHandlerMapping requestMappingHandlerMapping() {
        RequestMappingHandlerMapping mapping = new ApiVersionRequestMapping();
        mapping.setOrder(0);
        return mapping;
    }

    /**
     * 自定义验证工具，覆盖默认的验证工具
     * @return 自定义验证器
     */
    @Bean
    public Validator validator() {
        ValidatorFactory validatorFactory = Validation.byProvider(HibernateValidator.class)
                .configure()
                //启用快速失败，当验证条件有一个不符合时即返回错误
                .addProperty("hibernate.validator.fail_fast", properties.isFastValid() + "")
                .buildValidatorFactory();
        return validatorFactory.getValidator();
    }

    /**
     * 启用方法基本的验证，在Controller上增加{@link Validated}，支持直接对简单参数设定验证注解
     * @return 方法验证后置处理器
     */
    @Bean
    public MethodValidationPostProcessor methodValidationPostProcessor() {
        //启用方法级的验证
        MethodValidationPostProcessor postProcessor = new MethodValidationPostProcessor();
        postProcessor.setValidator(validator());
        return postProcessor;
    }
}

==> component-web-spring-boot-starter-2.0.8-sources.jar: com/bxm/newidea/component/config/ComponentWebAutoConfiguration.java <==
package com.bxm.newidea.component.config;

import com.bxm.newidea.component.mvc.ApiVersionRequestMapping;
import org.hibernate.validator.HibernateValidator;
import org.springframework.boot.autoconfigure.AutoConfigureAfter;
import org.springframework.boot.autoconfigure.web.servlet.WebMvcAutoConfiguration;
import org.springframework.boot.autoconfigure.web.servlet.WebMvcRegistrations;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.validation.annotation.Validated;
import org.springframework.validation.beanvalidation.MethodValidationPostProcessor;
import org.springframework.web.servlet.mvc.method.annotation.RequestMappingHandlerMapping;

import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;

/**
 * 公共的web配置
 *
 * @author liujia
 */
@Configuration
@AutoConfigureAfter(WebMvcAutoConfiguration.class)
@EnableConfigurationProperties(ComponentWebConfigurationProperties.class)
public class ComponentWebAutoConfiguration implements WebMvcRegistrations {

    private ComponentWebConfigurationProperties properties;

    public ComponentWebAutoConfiguration(ComponentWebConfigurationProperties properties) {
        this.properties = properties;
    }

    @Override
    public RequestMappingHandlerMapping getRequestMappingHandlerMapping() {
        RequestMappingHandlerMapping mapping = new ApiVersionRequestMapping();
        return mapping;
    }

    /**
     * 自定义验证工具，覆盖默认的验证工具
     *
     * @return 自定义验证器
     */
    @Bean
    public Validator validator() {
        ValidatorFactory validatorFactory = Validation.byProvider(HibernateValidator.class)
                .configure()
                //启用快速失败，当验证条件有一个不符合时即返回错误
                .failFast(properties.isFastValid())
                .buildValidatorFactory();
        return validatorFactory.getValidator();
    }

    /**
     * 启用方法基本的验证，在Controller上增加{@link Validated}，支持直接对简单参数设定验证注解
     *
     * @return 方法验证后置处理器
     */
    @Bean
    public MethodValidationPostProcessor methodValidationPostProcessor() {
        //启用方法级的验证
        MethodValidationPostProcessor postProcessor = new MethodValidationPostProcessor();
        postProcessor.setValidator(validator());
        return postProcessor;
    }
}
